==> streamingpool-ext-tensorics-1.1.3-sources.jar: org/streamingpool/ext/tensorics/conf/TensoricsStreamingConfiguration.java <==
// @formatter:off
/**
*
* This file is part of streaming pool (http://www.streamingpool.org).
* 
* Copyright (c) 2017-present, CERN. All rights reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
* 
*/
// @formatter:on

package org.streamingpool.ext.tensorics.conf;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.streamingpool.ext.tensorics.streamfactory.DetailedTensoricsExpressionStreamFactory;
import org.streamingpool.ext.tensorics.streamfactory.DiscreteFunctionStreamFactory;
import org.streamingpool.ext.tensorics.streamfactory.TensoricsBufferedStreamFactory;
import org.streamingpool.ext.tensorics.streamfactory.TensoricsExpressionStreamFactory;
import org.tensorics.core.resolve.engine.ResolvingEngine;

@Configuration
public class TensoricsStreamingConfiguration {

    @Autowired
    private ResolvingEngine resolvingEngine;

    @Bean
    public TensoricsExpressionStreamFactory tensoricsExpressionStreamFactory() {
        return new TensoricsExpressionStreamFactory();
    }

    @Bean
    public DetailedTensoricsExpressionStreamFactory detailedTensoricsExpressionStreamFactory() {
        return new DetailedTensoricsExpressionStreamFactory(resolvingEngine);
    }

    @Bean
    public TensoricsBufferedStreamFactory tensoricsBufferedStreamFactory() {
        return new TensoricsBufferedStreamFactory();
    }

    @Bean
    public DiscreteFunctionStreamFactory discreteFunctionStreamFactory() {
        return new DiscreteFunctionStreamFactory();
    }
}

==> streamingpool-ext-tensorics-1.4.1-sources.jar: org/streamingpool/ext/tensorics/conf/TensoricsStreamingConfiguration.java <==
// @formatter:off
/**
*
* This file is part of streaming pool (http://www.streamingpool.org).
* 
* Copyright (c) 2017-present, CERN. All rights reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
* 
*/
// @formatter:on

package org.streamingpool.ext.tensorics.conf;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.streamingpool.ext.tensorics.streamfactory.BufferedTensoricsExpressionStreamFactory;
import org.streamingpool.ext.tensorics.streamfactory.DetailedTensoricsExpressionStreamFactory;
import org.streamingpool.ext.tensorics.streamfactory.TensoricsExpressionStreamFactory;
import org.tensorics.core.resolve.engine.ResolvingEngine;

@Configuration
public class TensoricsStreamingConfiguration {

    @Bean
    public BufferedTensoricsExpressionStreamFactory bufferedTensoricsExpressionStreamFactory(
            ResolvingEngine resolvingEngine) {
        return new BufferedTensoricsExpressionStreamFactory(resolvingEngine);
    }

    @Bean
    public TensoricsExpressionStreamFactory tensoricsExpressionStreamFactory() {
        return new TensoricsExpressionStreamFactory();
    }

    @Bean
    public DetailedTensoricsExpressionStreamFactory detailedTensoricsExpressionStreamFactory(
            ResolvingEngine resolvingEngine) {
        return new DetailedTensoricsExpressionStreamFactory(resolvingEngine);
    }

}
